<?php $TRANSLATIONS = array(
"Pictures" => "Рисунки",
"Shared by" => "Опубликовано",
"Share" => "Открыть доступ",
"The \"Image Viewer\" application also need to be enabled to use this application." => "Для работы этого приложения необходимо включить приложение \"Image Viewer\"."
);
